@@ -9,11 +9,10 @@ from coref.internal.monad.internal import *
 from coref.ns import *
 from coref.mod import *
 from coref.cfg import nsCfgLoad, nsCfgFSLoad
-from coref.arrghs import nsArgs, nsCmd
+from coref.arrghs import nsArgs
 from coref.help import nsHelp
 from coref.internal.util import partial
 
 def NS(argv=sys.argv[1:], *cfg, **kw):
     ns = nsNS(argv, *cfg, **kw)
-    nsCmd(ns)
     return (ns, ns.V("/bin/f").value, ns.V("/bin/F").value)
